# Changelog

All notable changes to this project will be documented in this file.

## [0.0.3] - 2025-01-10

- Configuration file

### Added

## [0.0.2] - 2024-12-23

### Added

- Documentation
- Automated release pipeline

## [0.0.1] - 2024-12-14

### Added

- Initial release
- Interactive CLI mode
- Local RAG pipeline support
- Document management with ChromaDB
